summaryrefslogtreecommitdiffstats
path: root/juk/playlistsplitter.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:43:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:43:15 +0000
commite654398e46e37abf457b2b1122ab898d2c51c49f (patch)
treed39ee6440f3c3663c3ead84a2d4cc2d034667e96 /juk/playlistsplitter.h
parente4f29b18e19394b9352f52a6c0d0d0e3932cf511 (diff)
downloadtdemultimedia-e654398e46e37abf457b2b1122ab898d2c51c49f.tar.gz
tdemultimedia-e654398e46e37abf457b2b1122ab898d2c51c49f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1157644 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'juk/playlistsplitter.h')
-rw-r--r--juk/playlistsplitter.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/juk/playlistsplitter.h b/juk/playlistsplitter.h
index 0734ee05..cc163640 100644
--- a/juk/playlistsplitter.h
+++ b/juk/playlistsplitter.h
@@ -18,7 +18,7 @@
#include <kfiledialog.h>
-#include <qwidgetstack.h>
+#include <tqwidgetstack.h>
#include "playlistbox.h"
@@ -31,7 +31,7 @@ class TagEditor;
/**
* This is the main layout class of JuK. It should contain a PlaylistBox and
* a QWidgetStack of the Playlists.
*
* This class serves as a "mediator" (see "Design Patterns") between the JuK
* class and the playlist classes. Thus all access to the playlist classes from
@@ -43,12 +43,12 @@ class PlaylistSplitter : public QSplitter
Q_OBJECT
public:
- PlaylistSplitter(QWidget *parent, const char *name = 0);
+ PlaylistSplitter(TQWidget *parent, const char *name = 0);
virtual ~PlaylistSplitter();
PlaylistInterface *playlist() const { return m_playlistBox; }
- virtual bool eventFilter(QObject *watched, QEvent *event);
+ virtual bool eventFilter(TQObject *watched, TQEvent *event);
public slots:
virtual void setFocus();
@@ -58,7 +58,7 @@ private:
/**
* This returns a pointer to the first item in the playlist on the top
* of the QWidgetStack of playlists.
*/
Playlist *visiblePlaylist() const;
@@ -75,13 +75,13 @@ private slots:
*/
void slotShowSearchResults();
void slotPlaylistSelectionChanged();
- void slotPlaylistChanged(QWidget *w);
+ void slotPlaylistChanged(TQWidget *w);
private:
Playlist *m_newVisible;
PlaylistBox *m_playlistBox;
SearchWidget *m_searchWidget;
- QWidgetStack *m_playlistStack;
+ TQWidgetStack *m_playlistStack;
TagEditor *m_editor;
};
@@ -31,7 +31,7 @@ class TagEditor;
/**
* This is the main layout class of JuK. It should contain a PlaylistBox and
- * a QWidgetStack of the Playlists.
+ * a TQWidgetStack of the Playlists.
*
* This class serves as a "mediator" (see "Design Patterns") between the JuK
@@ -58,7 +58,7 @@ private:
/**
* This returns a pointer to the first item in the playlist on the top
- * of the QWidgetStack of playlists.
+ * of the TQWidgetStack of playlists.
*/
Playlist *visiblePlaylist() const;